==> haskell-time-compat-1.9.8-28-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-time-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-compat
version:              1.9.8
visibility:           public
id:                   time-compat-1.9.8-ITy6Cf33IaSAWRM66COV33
key:                  time-compat-1.9.8-ITy6Cf33IaSAWRM66COV33
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Ashley Yakeley
homepage:             https://github.com/haskellari/time-compat
synopsis:             Compatibility package for time
description:
    This packages tries to compat as much of @time@ features as possible.

    /TODO:/

    * Difference type @ParseTime@ and @FormatTime@ instances are missing.

    * Formatting varies depending on underlying @time@ version

    * @dayFractionToTimeOfDay@ on extreme values

category:             Time, Compatibility
abi:                  bae9c69e758aed4474a601389f81692d
exposed:              True
exposed-modules:
    Data.Time.Calendar.Compat Data.Time.Calendar.Easter.Compat
    Data.Time.Calendar.Julian.Compat Data.Time.Calendar.Month.Compat
    Data.Time.Calendar.MonthDay.Compat
    Data.Time.Calendar.OrdinalDate.Compat
    Data.Time.Calendar.Quarter.Compat
    Data.Time.Calendar.WeekDate.Compat Data.Time.Clock.Compat
    Data.Time.Clock.POSIX.Compat Data.Time.Clock.System.Compat
    Data.Time.Clock.TAI.Compat Data.Time.Compat Data.Time.Format.Compat
    Data.Time.Format.ISO8601.Compat Data.Time.LocalTime.Compat

hidden-modules:
    Data.Format Data.Time.Calendar.Private Data.Time.Calendar.Types
    Data.Time.Orphans

import-dirs:          /usr/lib/ghc-9.6.6/site-local/time-compat-1.9.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/time-compat-1.9.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/time-compat-1.9.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-time-compat
hs-libraries:         HStime-compat-1.9.8-ITy6Cf33IaSAWRM66COV33
depends:
    base-4.18.2.1 base-orphans-0.9.3-JybUSC3tjiTK5xbDkdemoL
    deepseq-1.4.8.1 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    template-haskell-2.20.0.0 time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-time-compat/html/time-compat.haddock
haddock-html:         /usr/share/doc/haskell-time-compat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-compat-1.9.8-30-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-time-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-compat
version:              1.9.8
visibility:           public
id:                   time-compat-1.9.8-BtHhA5KfmFIBqrg95bnRey
key:                  time-compat-1.9.8-BtHhA5KfmFIBqrg95bnRey
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Ashley Yakeley
homepage:             https://github.com/haskellari/time-compat
synopsis:             Compatibility package for time
description:
    This packages tries to compat as much of @time@ features as possible.

    /TODO:/

    * Difference type @ParseTime@ and @FormatTime@ instances are missing.

    * Formatting varies depending on underlying @time@ version

    * @dayFractionToTimeOfDay@ on extreme values

category:             Time, Compatibility
abi:                  7ecab335ef89d23a66363e66c91c1d37
exposed:              True
exposed-modules:
    Data.Time.Calendar.Compat Data.Time.Calendar.Easter.Compat
    Data.Time.Calendar.Julian.Compat Data.Time.Calendar.Month.Compat
    Data.Time.Calendar.MonthDay.Compat
    Data.Time.Calendar.OrdinalDate.Compat
    Data.Time.Calendar.Quarter.Compat
    Data.Time.Calendar.WeekDate.Compat Data.Time.Clock.Compat
    Data.Time.Clock.POSIX.Compat Data.Time.Clock.System.Compat
    Data.Time.Clock.TAI.Compat Data.Time.Compat Data.Time.Format.Compat
    Data.Time.Format.ISO8601.Compat Data.Time.LocalTime.Compat

hidden-modules:
    Data.Format Data.Time.Calendar.Private Data.Time.Calendar.Types
    Data.Time.Orphans

import-dirs:          /usr/lib/ghc-9.6.6/site-local/time-compat-1.9.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/time-compat-1.9.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/time-compat-1.9.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-time-compat
hs-libraries:         HStime-compat-1.9.8-BtHhA5KfmFIBqrg95bnRey
depends:
    base-4.18.2.1 base-orphans-0.9.3-8K2HHrVXqhTGZegxAcDUaG
    deepseq-1.4.8.1 hashable-1.4.7.0-LSmBhr9Bt59DsIlhOBFmCL
    template-haskell-2.20.0.0 time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-time-compat/html/time-compat.haddock
haddock-html:         /usr/share/doc/haskell-time-compat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
